==> mahara_1.4.0.orig.tar.gz: mahara-1.4.0/htdocs/blocktype/groupviews/lang/en.utf8/blocktype.groupviews.php <==
<?php
/**
 * Mahara: Electronic portfolio, weblog, resume builder and social networking
 * Copyright (C) 2006-2009 Catalyst IT Ltd and others; see:
 *                         http://wiki.mahara.org/Contributors
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * @package    mahara
 * @subpackage blocktype-groupinfo
 * @author     Liip AG
 * @license    http://www.gnu.org/copyleft/gpl.html GNU GPL
 * @copyright  (C) 2010 Liip AG http://www.liip.ch
 *
 */

defined('INTERNAL') || die();

$string['title'] = 'Group Pages';
$string['description'] = 'Display the pages related to the group';
$string['displaygroupviews'] = 'Display Group pages?';
$string['displaygroupviewsdesc'] = 'Group pages - pages created in the group';
$string['displaysharedviews'] = 'Display Shared pages?';
$string['displaysharedviewsdesc'] = 'Shared pages - pages shared by group members from their individual portfolio';
$string['defaulttitledescription'] = 'A default title will be generated if you leave the title field blank';

==> mahara_1.5.1.orig.tar.gz: mahara-1.5.1/htdocs/blocktype/groupviews/lang/en.utf8/blocktype.groupviews.php <==
<?php
/**
 * Mahara: Electronic portfolio, weblog, resume builder and social networking
 * Copyright (C) 2006-2009 Catalyst IT Ltd and others; see:
 *                         http://wiki.mahara.org/Contributors
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * @package    mahara
 * @subpackage blocktype-groupinfo
 * @author     Liip AG
 * @license    http://www.gnu.org/copyleft/gpl.html GNU GPL
 * @copyright  (C) 2010 Liip AG http://www.liip.ch
 *
 */

defined('INTERNAL') || die();

$string['title'] = 'Group pages';
$string['description'] = 'Display the pages related to the group';
$string['displaygroupviews'] = 'Display group pages';
$string['displaygroupviewsdesc'] = 'Group pages - pages created in the group';
$string['displaysharedviews'] = 'Display shared pages';
$string['displaysharedviewsdesc'] = 'Shared pages - pages shared by group members from their individual portfolios';
$string['defaulttitledescription'] = 'A default title will be generated if you leave the title field blank';
